@@ -48,7 +48,7 @@ def test_useragent_docomo():
                     assert ua.is_gps() == v, msg(ua, ua.is_gps(), v)
 
     for args in DATA:
-        yield ([inner] + list(args))
+        yield tuple([inner] + list(args))
 
 def test_display_default():
     # the following User-Agent doesn't exist at least in spring 2009
@@ -412,4 +412,21 @@ DATA = (
 ('DoCoMo/2.0 P06A(c100;TB;W20H13)', '2.0', '7.2', 'P06A', 100, True, 'P', '06A', {'status':'TB'}, (240, 320)),
 ('DoCoMo/2.0 P07A(c500;TB;W24H15)', '2.0', '7.2', 'P07A', 500, True, 'P', '07A', {'status':'TB'}, (240, 320), True),
 ('DoCoMo/2.0 N06A(c500;TB;W24H16)', '2.0', '7.2', 'N06A', 500, True, 'N', '06A', {'status':'TB'}, (240, 320), True),
+
+# Added 2009/5/26
+('DoCoMo/2.0 N06A2(c500;TB;W24H16)', '2.0', '7.2', 'N06A2', 500, True, 'N', '06A2', {'status':'TB'}, (240, 320), True),
+
+# Added 2009/5/27
+('DoCoMo/2.0 N06A3(c500;TB;W24H16)', '2.0', '7.2', 'N06A3', 500, True, 'N', '06A3', {'status':'TB'}, (240, 320), True),
+('DoCoMo/2.0 P07A3(c500;TB;W24H15)', '2.0', '7.2', 'P07A3', 500, True, 'P', '07A3', {'status':'TB'}, (240, 320), True),
+
+# Added 2009/6/5
+('DoCoMo/2.0 F09A3(c500;TB;W24H16)', '2.0', '7.2', 'F09A3', 500, True, 'F', '09A3', {'status':'TB'}, (240, 320), True),
+
+# Added 2009/6/18
+('DoCoMo/2.0 SH05A3(c500;TB;W24H14)', '2.0', '7.2', 'SH05A3', 500, True, 'SH', '05A3', {'status':'TB'}, (240, 320), True),
+('DoCoMo/2.0 SH06A3(c500;TB;W24H14)', '2.0', '7.2', 'SH06A3', 500, True, 'SH', '06A3', {'status':'TB'}, (240, 320), True),
+
+# Added 2009/7/2
+('DoCoMo/2.0 P10A(c100;TB;W24H15)', '2.0', '7.2', 'P10A', 100, True, 'P', '10A', {'status':'TB'}, (240, 320), False),
 )
